# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`vault`](#vault): install hashicorp vault

#### Private Classes

* `vault::config`: This class is called from vault for service config
* `vault::install`
* `vault::params`: This class is meant to be called from vault. It sets variables according to platform.
* `vault::service`

## Classes

### <a name="vault"></a>`vault`

install hashicorp vault

#### Parameters

The following parameters are available in the `vault` class:

* [`user`](#-vault--user)
* [`manage_user`](#-vault--manage_user)
* [`group`](#-vault--group)
* [`manage_group`](#-vault--manage_group)
* [`bin_dir`](#-vault--bin_dir)
* [`config_dir`](#-vault--config_dir)
* [`config_mode`](#-vault--config_mode)
* [`purge_config_dir`](#-vault--purge_config_dir)
* [`download_url`](#-vault--download_url)
* [`download_url_base`](#-vault--download_url_base)
* [`download_extension`](#-vault--download_extension)
* [`service_name`](#-vault--service_name)
* [`service_provider`](#-vault--service_provider)
* [`service_options`](#-vault--service_options)
* [`manage_repo`](#-vault--manage_repo)
* [`manage_service`](#-vault--manage_service)
* [`num_procs`](#-vault--num_procs)
* [`api_addr`](#-vault--api_addr)
* [`version`](#-vault--version)
* [`extra_config`](#-vault--extra_config)
* [`enable_ui`](#-vault--enable_ui)
* [`arch`](#-vault--arch)
* [`os`](#-vault--os)
* [`manage_download_dir`](#-vault--manage_download_dir)
* [`download_dir`](#-vault--download_dir)
* [`package_ensure`](#-vault--package_ensure)
* [`package_name`](#-vault--package_name)
* [`install_method`](#-vault--install_method)
* [`manage_file_capabilities`](#-vault--manage_file_capabilities)
* [`disable_mlock`](#-vault--disable_mlock)
* [`max_lease_ttl`](#-vault--max_lease_ttl)
* [`default_lease_ttl`](#-vault--default_lease_ttl)
* [`telemetry`](#-vault--telemetry)
* [`disable_cache`](#-vault--disable_cache)
* [`seal`](#-vault--seal)
* [`ha_storage`](#-vault--ha_storage)
* [`listener`](#-vault--listener)
* [`manage_storage_dir`](#-vault--manage_storage_dir)
* [`storage`](#-vault--storage)
* [`manage_service_file`](#-vault--manage_service_file)
* [`service_ensure`](#-vault--service_ensure)
* [`service_enable`](#-vault--service_enable)
* [`manage_config_file`](#-vault--manage_config_file)
* [`download_filename`](#-vault--download_filename)
* [`manage_config_dir`](#-vault--manage_config_dir)

##### <a name="-vault--user"></a>`user`

Data type: `Any`

Customise the user vault runs as, will also create the user unless `manage_user` is false.

Default value: `'vault'`

##### <a name="-vault--manage_user"></a>`manage_user`

Data type: `Any`

Whether or not the module should create the user.

Default value: `true`

##### <a name="-vault--group"></a>`group`

Data type: `Any`

Customise the group vault runs as, will also create the user unless `manage_group` is false.

Default value: `'vault'`

##### <a name="-vault--manage_group"></a>`manage_group`

Data type: `Any`

Whether or not the module should create the group.

Default value: `true`

##### <a name="-vault--bin_dir"></a>`bin_dir`

Data type: `Any`

Directory the vault executable will be installed in.

Default value: `$vault::params::bin_dir`

##### <a name="-vault--config_dir"></a>`config_dir`

Data type: `Any`

Directory the vault configuration will be kept in.

Default value: `if $install_method == 'repo' and $manage_repo { '/etc/vault.d' } else { '/etc/vault'`

##### <a name="-vault--config_mode"></a>`config_mode`

Data type: `Any`

Mode of the configuration file (config.json). Defaults to '0750'

Default value: `'0750'`

##### <a name="-vault--purge_config_dir"></a>`purge_config_dir`

Data type: `Any`

Whether the `config_dir` should be purged before installing the generated config.

Default value: `true`

##### <a name="-vault--download_url"></a>`download_url`

Data type: `Any`

Manual URL to download the vault zip distribution from.

Default value: `undef`

##### <a name="-vault--download_url_base"></a>`download_url_base`

Data type: `Any`

Hashicorp base URL to download vault zip distribution from.

Default value: `'https://releases.hashicorp.com/vault/'`

##### <a name="-vault--download_extension"></a>`download_extension`

Data type: `Any`

The extension of the vault download

Default value: `'zip'`

##### <a name="-vault--service_name"></a>`service_name`

Data type: `Any`

Customise the name of the system service

Default value: `'vault'`

##### <a name="-vault--service_provider"></a>`service_provider`

Data type: `Any`

Customise the name of the system service provider; this
also controls the init configuration files that are installed.

Default value: `$facts['service_provider']`

##### <a name="-vault--service_options"></a>`service_options`

Data type: `Any`

Extra argument to pass to `vault server`, as per: `vault server --help`

Default value: `''`

##### <a name="-vault--manage_repo"></a>`manage_repo`

Data type: `Boolean`

Configure the upstream HashiCorp repository. Only relevant when $nomad::install_method = 'repo'.

Default value: `$vault::params::manage_repo`

##### <a name="-vault--manage_service"></a>`manage_service`

Data type: `Any`

Instruct puppet to manage service or not

Default value: `true`

##### <a name="-vault--num_procs"></a>`num_procs`

Data type: `Any`

Sets the GOMAXPROCS environment variable, to determine how many CPUs Vault
can use. The official Vault Terraform install.sh script sets this to the
output of ``nprocs``, with the comment, "Make sure to use all our CPUs,
because Vault can block a scheduler thread". Default: number of CPUs
on the system, retrieved from the ``processorcount`` Fact.

Default value: `$facts['processors']['count']`

##### <a name="-vault--api_addr"></a>`api_addr`

Data type: `Optional[String]`

Specifies the address (full URL) to advertise to other Vault servers in the
cluster for client redirection. This value is also used for plugin backends.
This can also be provided via the environment variable VAULT_API_ADDR. In
general this should be set as a full URL that points to the value of the
listener address

Default value: `undef`

##### <a name="-vault--version"></a>`version`

Data type: `Any`

The version of Vault to install

Default value: `'1.12.0'`

##### <a name="-vault--extra_config"></a>`extra_config`

Data type: `Hash`



Default value: `{}`

##### <a name="-vault--enable_ui"></a>`enable_ui`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-vault--arch"></a>`arch`

Data type: `Any`



Default value: `$vault::params::arch`

##### <a name="-vault--os"></a>`os`

Data type: `Any`



Default value: `downcase($facts['kernel'])`

##### <a name="-vault--manage_download_dir"></a>`manage_download_dir`

Data type: `Any`



Default value: `false`

##### <a name="-vault--download_dir"></a>`download_dir`

Data type: `Any`



Default value: `'/tmp'`

##### <a name="-vault--package_ensure"></a>`package_ensure`

Data type: `Any`



Default value: `'installed'`

##### <a name="-vault--package_name"></a>`package_name`

Data type: `Any`



Default value: `'vault'`

##### <a name="-vault--install_method"></a>`install_method`

Data type: `Any`



Default value: `$vault::params::install_method`

##### <a name="-vault--manage_file_capabilities"></a>`manage_file_capabilities`

Data type: `Any`



Default value: `undef`

##### <a name="-vault--disable_mlock"></a>`disable_mlock`

Data type: `Any`



Default value: `undef`

##### <a name="-vault--max_lease_ttl"></a>`max_lease_ttl`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-vault--default_lease_ttl"></a>`default_lease_ttl`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-vault--telemetry"></a>`telemetry`

Data type: `Optional[Hash]`



Default value: `undef`

##### <a name="-vault--disable_cache"></a>`disable_cache`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-vault--seal"></a>`seal`

Data type: `Optional[Hash]`



Default value: `undef`

##### <a name="-vault--ha_storage"></a>`ha_storage`

Data type: `Optional[Hash]`



Default value: `undef`

##### <a name="-vault--listener"></a>`listener`

Data type: `Variant[Hash, Array[Hash]]`



Default value: `{ 'tcp' => { 'address' => '127.0.0.1:8200', 'tls_disable' => 1 }, }`

##### <a name="-vault--manage_storage_dir"></a>`manage_storage_dir`

Data type: `Any`



Default value: `false`

##### <a name="-vault--storage"></a>`storage`

Data type: `Hash`



Default value: `{ 'file' => { 'path' => '/var/lib/vault' } }`

##### <a name="-vault--manage_service_file"></a>`manage_service_file`

Data type: `Optional[Boolean]`



Default value: `$vault::params::manage_service_file`

##### <a name="-vault--service_ensure"></a>`service_ensure`

Data type: `Any`



Default value: `'running'`

##### <a name="-vault--service_enable"></a>`service_enable`

Data type: `Any`



Default value: `true`

##### <a name="-vault--manage_config_file"></a>`manage_config_file`

Data type: `Any`



Default value: `true`

##### <a name="-vault--download_filename"></a>`download_filename`

Data type: `Any`



Default value: `'vault.zip'`

##### <a name="-vault--manage_config_dir"></a>`manage_config_dir`

Data type: `Boolean`

enable/disable the directory management. not required for package based installations

Default value: `$install_method == 'archive'`

